import {select, 
        csv, 
        scaleLinear, 
        scaleTime,
        line,
        extent, 
        axisLeft, 
        axisBottom,
        curveBasis,
        format} from 'd3';
const svg = d3.select("svg");

const width = +svg.attr("width");
const height = +svg.attr("height"); //unary +-operator converts string to number

const render = data => {
  const Title = 'Cars';
  const xValue = d => d.timestamp;
  const xAxisLabel = 'Time';
  
  const yValue = d => d.temperature;
  const yAxisLabel = 'Temperature';

  
  const margin = {left: 150, top:40, right: 40, bottom:60};
  
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([ innerHeight, 0])
  	.nice()
;
  
  const yAxis = axisLeft(yScale); //returns a function 
  const xAxis = axisBottom(xScale); //returns a function 
  const xAxisTickFormat = n => format('.3s')(n).replace('G', 'B'); 
  
  const g = svg.append('g')
  .attr('transform', `translate(${margin.left}, ${margin.top})`);
    
  //yAxis(g.append('g')); Which is equal to:
  const yAxisGroup =
  g.append('g').call(yAxis.tickSize(-innerWidth));
  	//.selectAll('.domain, .tick line').remove();
  
  
  yAxisGroup.append('text')
    .attr('class', 'axis-label')
  	//.attr('fill', 'black')
    .attr('x', -innerHeight/2)
    .attr('text-anchor', 'middle')
  	.attr('y', -70)
  	.text(yAxisLabel)
    .attr('transform', `rotate(-90)`);
  //translate(${-100, 0})`);
;

  
  const xAxisGroup =   g.append('g').call(
    xAxis
    .tickSize(-innerHeight)
  	.tickPadding(10)
  	)
    .attr('transform', `translate(0, ${innerHeight})`);

  xAxisGroup.select('.domain').remove();
  
  xAxisGroup.append('text')
  	.attr('y', 50)
  	.attr('x', innerWidth/2)
  	//.attr('fill', 'black')
  	.text(xAxisLabel);

 
  g.append('text')
  	.attr('y', -10)
  	.text(Title);

  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  		.attr('class', 'path-line')
    	.attr('d', lineGenerator(data))
  		;
  
};
csv('data.csv').then(data => {
  data.forEach(d=> {
  d.temperature = +d.temperature;
    //20200531T0000
  var dateTime = ''.concat(
    						d.timestamp.substring(0,4) ,
      					 "-" ,
                 d.timestamp.substring(4,6) ,
  							 "-" ,
     						 d.timestamp.substring(6,8) ,
      					 "T" ,
     						 d.timestamp.substring(9,11) ,
      				 ":" ,
     						 d.timestamp.substring(11,13) ,
     						 "Z"
      					 )
                   ;
  d.timestamp = new Date(dateTime);
    
  })
  render(data);
  console.log(data);


})
